'''
Some notes to this mapping:
- Most ipa substrings match according to their simplied substring (ignore ̯ ˈ etc. since it doesn't change the katakana pronunciation)
- Some ipa substrings are not simplified because of some edge cases
    -> like aːɐ̯ in "Januar" (ˈjanuaːɐ̯), the latter a is silent for more natural pronunciation
- The character ː is mapped as ー, because it is to be pronounced longer, the other special characters map to an empty string
'''
GERMAN_IPA_TO_KATAKANA_MAP = {
    # Vowels
    '\u0061': '\u30A2',                                 # a -> ア (word: "alt", ipa: "alt")
    '\u0250': '\u30A2',                                 # ɐ -> ア (word: "Schleier", ipa: "ˈʃlaɪ̯ɐ")
    '\u0065': '\u30A8',                                 # e -> エ (word: "er", ipa: "eːɐ̯")
    '\u0259': '\u30A8',                                 # ə -> エ (word: "Familie", ipa: "faˈmiːli̯ə")
    '\u025B': '\u30A8',                                 # ɛ -> エ (word: "Entscheiden", ipa: "ɛntˈʃaɪ̯dn̩")
    '\u0069': '\u30A4',                                 # i -> イ (word: "ihr", ipa: "iːɐ̯")
    '\u026A': '\u30A4',                                 # ɪ -> イ (word: "Deutschland", ipa: "ˈdɔɪ̯t͡ʃlant")
    '\u006F': '\u30AA',                                 # o -> オ (word: "violett", ipa: "vioˈlɛt")
    '\u0254': '\u30AA',                                 # ɔ -> オ (word: "Oktober", ipa: "ɔkˈtoːbɐ")
    '\u0075': '\u30A6',                                 # u -> ウ (word: "Uhr", ipa: "uːɐ̯")
    '\u028A': '\u30A6',                                 # ʊ -> ウ (word: "und", ipa: "ʊnt")
    '\u0079': '\u30E6',                                 # y -> ユ (word: "über", ipa: "ˈyːbɐ")
    '\u028F': '\u30E6',                                 # ʏ -> ユ (word: "üppig", ipa: "ˈʏpɪç")
    '\u00F8': '\u30AA\u30A7',                           # ø -> オェ (word: "Ökologie", ipa: "ˌøkoloˈɡiː")
    '\u0153': '\u30AA\u30A7',                           # œ -> オェ (word: "öffnen", ipa: "ˈœfnən")
    '\u0061\u02D0\u0250\u032F': '\u30A2\u30FC',         # aːɐ̯  -> アー (word: "Januar", ipa: "ˈjanuaːɐ̯")

    # B
    '\u0062': '\u30D6',                                 # b -> ブ (word: "Brief", ipa: "bʁiːf")
    '\u0062\u0061': '\u30D0',                           # ba -> バ (word: "Ballon", ipa: "baˈlɔŋ")
    '\u0062\u0250': '\u30D0',                           # bɐ -> バ (word: "Oktober", ipa: "ɔkˈtoːbɐ")
    '\u0062\u0065': '\u30D9',                           # be -> ベ (word: "betoniert", ipa: "betoˈniːɐ̯t")
    '\u0062\u0259': '\u30D9',                           # bə -> ベ (word: "Brieftaube", ipa: "ˈbʁiːfˌtaʊ̯bə")
    '\u0062\u025B': '\u30D9',                           # bɛ -> ベ (word: "Bett", ipa: "ɔkˈtoːbɐ")
    '\u0062\u0069': '\u30D3',                           # bi -> ビ (word: "Bier", ipa: "biːɐ̯")
    '\u0062\u026A': '\u30D3',                           # bɪ -> ビ (word: "Bitte", ipa: "ˈbɪtə")
    '\u0062\u006F': '\u30DC',                           # bo -> ボ (word: "Boot", ipa: "boːt")
    '\u0062\u0254': '\u30DC',                           # bɔ -> ボ (word: "Bäume", ipa: "ˈbɔɪ̯mə")
    '\u0062\u0075': '\u30D6',                           # bu -> ブ (word: "schnabulieren", ipa: "ʃnabuˈliːʁən")
    '\u0062\u028A': '\u30D6',                           # bʊ -> ブ (word: "Tribus", ipa: "ˈtʁiːbʊs")
    '\u0062\u0079': '\u30D3\u30E5',                     # by -> ビュ (word: "Bügel", ipa: "ˈbyːɡl̩")
    '\u0062\u028F': '\u30D3\u30E5',                     # bʏ -> ビュ (word: "büffeln", ipa: "ˈbʏfl̩n")
    '\u0062\u00F8': '\u30DC\u30A7',                     # bø -> ボェ (word: "Bögen", ipa: "ˈbøːɡn̩")
    '\u0062\u0153': '\u30DC\u30A7',                     # bœ -> ボェ (word: "Börse", ipa: "ˈbœʁzə")
    '\u0062\u006C\u0329': '\u30D9\u30EB',               # bl̩ -> ベル (word: "Wコirbel", ipa: "ˈvɪʁbl̩")
    '\u0062\u006E\u0329': '\u30D9\u30F3',               # bn̩ -> ベン (word: "lieben", ipa: "ˈliːbn̩")

    # C
    '\u00E7': '\u30C3\u30D2',                           # ç -> ッヒ (Short "ch" anywhere not previously covered as "niCHt")
    '\u00E7\u0061': '\u30B7\u30E3',                     # ça -> シャ (word: "Mechaniker", ipa: "meˈçaːnɪkɐ")
    '\u00E7\u0250': '\u30B7\u30E3',                     # çɐ -> シャ (word: "Stammbücher", ipa: "ˈʃtamˌbyːçɐ")
    '\u00E7\u0065': '\u30B1',                           # çe -> ケ (word: "Elektrochemie", ipa: "eˌlɛktʁoçeˈmiː")
    '\u00E7\u0259': '\u30C3\u30D2\u30A7',               # çə -> ッヒェ (word: "Teilchen", ipa: "ˈtaɪ̯lçən")
    '\u00E7\u025B': '\u30B7\u30A7',                     # çɛ -> シェ (word: "Archäologe", ipa: "aʁçɛoˈloːɡə")
    '\u00E7\u0069': '\u30AD',                           # çi -> キ (word: "China", ipa: "ˈçiːna")
    '\u00E7\u026A': '\u30C3\u30D2',                     # çɪ -> ッヒ (word: "Griechisch", ipa: "ˈɡʁiːçɪʃ")
    '\u00E7\u006F': '\u30B7\u30A9',                     # ço -> シォ (word: "Psychopath", ipa: "psyçoˈpaːt")
    '\u00E7\u0254': '\u30B3',                           # çɔ -> コ (word: "Chondrom", ipa: "çɔnˈdʁoːm")
    '\u00E7\u0075': '\u30B7\u30E5',                     # çu -> シュ (word: "Ischurie", ipa: "ɪsçuˈʁiː")
    '\u00E7\u028A': '\u30B7\u30E5',                     # çʊ -> シュ (word: "Gleichung", ipa: "ˈɡlaɪ̯çʊŋ")
    '\u00E7\u0079': '\u30B7\u30E5',                     # çy -> シュ (word: "Mesenchym", ipa: "mezɛnˈçyːm")
    '\u00E7\u028F': '\u30B7\u30E5',                     # çʏ -> シュ (no word for this mapping yet)
    '\u00E7\u00F8': '\u30B7\u30E7',                     # çø -> ショ (no word for this mapping yet)
    '\u00E7\u0153': '\u30B7\u30E7',                     # çœ -> ショ (no word for this mapping yet)
    '\u00E7\u006C\u0329': '\u30C3\u30D2\u30A7\u30EB',   # çl̩ -> ッヒェル (word: "Sichel", ipa: "ˈzɪçl̩")
    '\u00E7\u006E\u0329': '\u30C3\u30D2\u30A7\u30F3',   # çn̩ -> ッヒェン (Short "chen" as "reCHEN")

    # D
    '\u0064': '\u30C9',                                 # d -> ド (word: "Drei", ipa: "dʁaɪ̯")
    '\u0064\u0061': '\u30C0',                           # da -> ダ (word: "das", ipa: "das")
    '\u0064\u0250': '\u30C0',                           # dɐ -> ダ (word: "Bruder", ipa: "ˈbʁuːdɐ")
    '\u0064\u0065': '\u30C7',                           # de -> デ (word: "Dezember", ipa: "deˈt͡sɛmbɐ")
    '\u0064\u0259': '\u30C7',                           # də -> デ (word: "Stunde", ipa: "ˈʃtʊndə")
    '\u0064\u025B': '\u30C7',                           # dɛ -> デ (word: "des", ipa: "dɛs")
    '\u0064\u0069': '\u30C7\u30A3',                     # di -> ディ (word: "die", ipa: "diː")
    '\u0064\u026A': '\u30C7\u30A3',                     # dɪ -> ディ (word: "Dichter", ipa: "ˈdɪçtɐ")
    '\u0064\u006F': '\u30C9',                           # do -> ド (word: "Subordo", ipa: "ˌzʊpˈʔɔʁdo")
    '\u0064\u0254': '\u30C9',                           # dɔ -> ド (word: "Dorf", ipa: "dɔʁf")
    '\u0064\u0075': '\u30C9\u30A5',                     # du -> ドゥ (word: "du", ipa: "duː")
    '\u0064\u028A': '\u30C9\u30A5',                     # dʊ -> ドゥ (word: "Bildung", ipa: "ˈbɪldʊŋ")
    '\u0064\u0079': '\u30C7\u30E5',                     # dy -> デュ (word: "dünn", ipa: "dʏn")
    '\u0064\u028F': '\u30C7\u30E5',                     # dʏ -> デュ (word: "Dünen", ipa: "ˈdyːnən")
    '\u0064\u00F8': '\u30C9\u30A7',                     # dø -> ドェ (word: "Gedöns", ipa: "ɡəˈdøːns")
    '\u0064\u0153': '\u30C9\u30A7',                     # dœ -> ドェ (word: "Döner", ipa: "ˈdœnɛr")
    '\u0064\u006C\u0329': '\u30C7\u30EB',               # dl̩ -> デル (word: "wandeln", ipa: "ˈvandl̩n")
    '\u0064\u006E\u0329': '\u30C7\u30F3',               # dn̩ -> デン (word: "Frieden", ipa: "ˈfʁiːdn̩")

    # F
    '\u0066': '\u30D5',                                 # f -> フ (word: "Frieden", ipa: "ˈfʁiːdn̩")
    '\u0066\u0061': '\u30D5\u30A1',                     # fa -> ファ (word: "Luftfahrt", ipa: "ˈlʊftˌfaːɐ̯t")
    '\u0066\u0250': '\u30D5\u30A1',                     # fɐ -> ファ (word: "belfern", ipa: "ˈbɛlfɐn")
    '\u0066\u0065': '\u30D5\u30A7',                     # fe -> フェ (word: "Februar", ipa: "ˈfeːbʁuaːɐ̯")
    '\u0066\u0259': '\u30D5\u30A7',                     # fə -> フェ (word: "Hilfe", ipa: "ˈhɪlfə")
    '\u0066\u025B': '\u30D5\u30A7',                     # fɛ -> フェ (word: "versank", ipa: "fɛɐ̯ˈzaŋk")
    '\u0066\u0069': '\u30D5\u30A3',                     # fi -> フィ (word: "vielleicht", ipa: "fiˈlaɪ̯çt")
    '\u0066\u026A': '\u30D5\u30A3',                     # fɪ -> フィ (word: "Austernfischer", ipa: "ˈaʊ̯stɐnˌfɪʃɐ")
    '\u0066\u006F': '\u30D5\u30A9',                     # fo -> フォ (word: "vor", ipa: "foːɐ̯")
    '\u0066\u0254': '\u30D5\u30A9',                     # fɔ -> フォ (word: "Feuer", ipa: "ˈfɔɪ̯ɐ")
    '\u0066\u0075': '\u30D5',                           # fu -> フ (word: "Fug", ipa: "fuːk")
    '\u0066\u028A': '\u30D5',                           # fʊ -> フ (word: "Fundort", ipa: "ˈfʊntˌʔɔʁt")
    '\u0066\u0079': '\u30D5\u30E5',                     # fy -> フュ (word: "Subphylum", ipa: "ˌzʊpˈfyːlʊm")
    '\u0066\u028F': '\u30D5\u30E5',                     # fʏ -> フュ (word: "fünf", ipa: "fʏnf")
    '\u0066\u00F8': '\u30D5\u30A9\u30A7',               # fø -> フォェ (word: "vögeln", ipa: "ˈføːɡl̩n")
    '\u0066\u0153': '\u30D5\u30A9\u30A7',               # fœ -> フォェ (word: "Förderturm", ipa: "ˈfœʁdɐˌtʊʁm")
    '\u0066\u006C\u0329': '\u30D5\u30A7\u30EB',         # fl̩ -> フェル (word: "büffeln", ipa: "ˈbʏfl̩n")
    '\u0066\u006E\u0329': '\u30D5\u30A7\u30F3',         # fn̩ -> フェン (word: "kaufen", ipa: "ˈkaʊ̯fn̩")

    # G
    '\u0261': '\u30B0',                                 # ɡ -> グ (word: "grün", ipa: "ɡʁyːn")
    '\u0067': '\u30B0',                                 # g -> グ (word: "grün", ipa: "ɡʁyːn")
    '\u0261\u0061': '\u30AC',                           # ɡa -> ガ (word: "Garçonnière", ipa: "ɡaʁsɔˈni̯ɛːʁə")
    '\u0067\u0061': '\u30AC',                           # ga -> ガ (word: "Garçonnière", ipa: "ɡaʁsɔˈni̯ɛːʁə")
    '\u0261\u0250': '\u30AC',                           # ɡɐ -> ガ (word: "Karthager", ipa: "kaʁˈtaːɡɐ")
    '\u0067\u0250': '\u30AC',                           # gɐ -> ガ (word: "Karthager", ipa: "kaʁˈtaːɡɐ")
    '\u0261\u0065': '\u30B2',                           # ɡe -> ゲ (word: "Subgenus", ipa: "ˌzʊpˈɡeːnʊs")
    '\u0067\u0065': '\u30B2',                           # ge -> ゲ (word: "Subgenus", ipa: "ˌzʊpˈɡeːnʊs")
    '\u0261\u0259': '\u30B2',                           # ɡə -> ゲ (word: "Angebot", ipa: "ˈanɡəˌboːt")
    '\u0067\u0259': '\u30B2',                           # gə -> ゲ (word: "Angebot", ipa: "ˈanɡəˌboːt")
    '\u0261\u025B': '\u30B2',                           # ɡɛ -> ゲ (word: "vulgär", ipa: "vʊlˈɡɛːɐ̯")
    '\u0067\u025B': '\u30B2',                           # gɛ -> ゲ (word: "vulgär", ipa: "vʊlˈɡɛːɐ̯")
    '\u0261\u0069': '\u30AE',                           # ɡi -> ギ (word: "Biologie", ipa: "ˌbioloˈɡiː")
    '\u0067\u0069': '\u30AE',                           # gi -> ギ (word: "Biologie", ipa: "ˌbioloˈɡiː")
    '\u0261\u026A': '\u30AE',                           # ɡɪ -> ギ (word: "Gilbhart", ipa: "ˈɡɪlphaʁt")
    '\u0067\u026A': '\u30AE',                           # gɪ -> ギ (word: "Gilbhart", ipa: "ˈɡɪlphaʁt")
    '\u0261\u006F': '\u30B4',                           # ɡo -> ゴ (word: "Golem", ipa: "ˈɡoːlɛm")
    '\u0067\u006F': '\u30B4',                           # go -> ゴ (word: "Golem", ipa: "ˈɡoːlɛm")
    '\u0261\u0254': '\u30B4',                           # ɡɔ -> ゴ (word: "Gott", ipa: "ɡɔt")
    '\u0067\u0254': '\u30B4',                           # gɔ -> ゴ (word: "Gott", ipa: "ɡɔt")
    '\u0261\u0075': '\u30B0',                           # ɡu -> グ (word: "Figur", ipa: "fiˈɡuːɐ̯")
    '\u0067\u0075': '\u30B0',                           # gu -> グ (word: "Figur", ipa: "fiˈɡuːɐ̯")
    '\u0261\u028A': '\u30B0',                           # ɡʊ -> グ (word: "Gummibär", ipa: "ˈɡʊmibɛːɐ̯")
    '\u0067\u028A': '\u30B0',                           # gʊ -> グ (word: "Gummibär", ipa: "ˈɡʊmibɛːɐ̯")
    '\u0261\u0079': '\u30AE\u30E5',                     # ɡy -> ギュ (word: "Güte", ipa: "ˈɡyːtə")
    '\u0067\u0079': '\u30AE\u30E5',                     # gy -> ギュ (word: "Güte", ipa: "ˈɡyːtə")
    '\u0261\u028F': '\u30AE\u30E5',                     # ɡʏ -> ギュ (word: "Gürtel", ipa: "ˈɡʏʁtl̩")
    '\u0067\u028F': '\u30AE\u30E5',                     # gʏ -> ギュ (word: "Gürtel", ipa: "ˈɡʏʁtl̩")
    '\u0261\u00F8': '\u30B4\u30A7',                     # ɡø -> ゴェ (word: "Göre", ipa: "ˈɡøːʁə")
    '\u0067\u00F8': '\u30B4\u30A7',                     # gø -> ゴェ (word: "Göre", ipa: "ˈɡøːʁə")
    '\u0261\u0153': '\u30B4\u30A7',                     # ɡœ -> ゴェ (word: "gönnen", ipa: "ˈɡœnən")
    '\u0067\u0153': '\u30B4\u30A7',                     # gœ -> ゴェ (word: "gönnen", ipa: "ˈɡœnən")
    '\u0261\u006C\u0329': '\u30B2\u30EB',               # ɡl̩ -> ゲル (word: "Daumenregel", ipa: "ˈdaʊ̯mənˌʁeːɡl̩")
    '\u0067\u006C\u0329': '\u30B2\u30EB',               # gl̩ -> ゲル (word: "Daumenregel", ipa: "ˈdaʊ̯mənˌʁeːɡl̩")
    '\u0261\u006E\u0329': '\u30B2\u30F3',               # ɡn̩ -> ゲン (word: "Kriegen", ipa: "ˈkʁiːɡn̩")
    '\u0067\u006E\u0329': '\u30B2\u30F3',               # gn̩ -> ゲン (word: "Kriegen", ipa: "ˈkʁiːɡn̩")
    '\u0261\u014B\u030D': '\u30B2\u30F3',               # ɡŋ̍ -> ゲン (word: "Morgen", ipa: "ˈmɔʁɡŋ̍")
    '\u0067\u014B\u030D': '\u30B2\u30F3',               # gŋ̍ -> ゲン (word: "Morgen", ipa: "ˈmɔʁɡŋ̍")

    # H
    '\u0068\u0061': '\u30CF',                           # ha -> ハ (word: "Hallo", ipa: "haˈloː")
    '\u0068\u0250': '\u30CF',                           # hɐ -> ハ (no word for this mapping yet)
    '\u0068\u025B': '\u30D8',                           # he -> ヘ (word: "Herzog", ipa: "ˈhɛʁt͡soːk")
    '\u0068\u0259': '\u30D8',                           # hə -> ヘ (word: "Teheran", ipa: "ˈteːhəʁaːn")
    '\u0068\u025B': '\u30D8',                           # hɛ -> ヘ (word: "Herzog", ipa: "ˈhɛʁt͡soːk")
    '\u0068\u0069': '\u30D2',                           # hi -> ヒ (word: "hier", ipa: "hiːɐ̯")
    '\u0068\u026A': '\u30D2',                           # hɪ -> ヒ (word: "Hilfe", ipa: "ˈhɪlfə")
    '\u0068\u006F': '\u30DB',                           # ho -> ホ (word: "Friedhof", ipa: "ˈfʁiːtˌhoːf")
    '\u0068\u0254': '\u30DB',                           # hɔ -> ホ (word: "heute", ipa: "ˈhɔɪ̯tə")
    '\u0068\u0075': '\u30D5',                           # hu -> フ (word: "humide", ipa: "huˈmiːdə")
    '\u0068\u028A': '\u30D5',                           # hʊ -> フ (word: "Hund", ipa: "hʊnt")
    '\u0068\u0079': '\u30D2\u30E5',                     # hy -> ヒュ (word: "Hügel", ipa: "ˈhyːɡl̩")
    '\u0068\u028F': '\u30D2\u30E5',                     # hʏ -> ヒュ (word: "Hypnose", ipa: "hʏpˈnoːzə")
    '\u0068\u00F8': '\u30DB\u30A7',                     # hø -> ホェ (word: "Hörensagen", ipa: "ˈhøːʁənˌzaːɡn̩")
    '\u0068\u0153': '\u30DB\u30A7',                     # hœ -> ホェ (word: "Hölle", ipa: "ˈhœlə")

    # J
    '\u006A\u0061': '\u30E4',                           # ja -> ヤ (word: "Japan", ipa: "ˈjaːpan")
    '\u006A\u0065': '\u30A4\u30A7',                     # je -> イェ (word: "Jesus", ipa: "ˈjeːzʊs")
    '\u006A\u0069': '\u30B8',                           # ji -> ジ (word: "oktroyieren", ipa: "ɔktʁo̯aˈjiːʁən")
    '\u006A\u028A': '\u30E6',                           # jʊ -> ユ (word: "Junge", ipa: "ˈjʊŋə")
    '\u006A\u0075': '\u30E6',                           # ju -> ユ (word: "Juni", ipa: "ˈjuːni")
    '\u0292\u0259': '\u30B8\u30A7',                     # ʒə -> ジェ (word: "Orange", ipa: "oˈʁɑ̃ːʒə") (French "je" as in "Orange")

    # K
    '\u006B': '\u30AF',                                 # k -> ク (word: "klein", ipa: "klaɪ̯n")
    '\u006B\u0061': '\u30AB',                           # ka -> カ (word: "kein", ipa: "kaɪ̯n")
    '\u006B\u0250': '\u30AB',                           # kɐ -> カ (word: "medioker", ipa: "ˌmeˈdi̯oːkɐ")
    '\u006B\u0065': '\u30B1',                           # ke -> ケ (word: "Paket", ipa: "paˈkeːt")
    '\u006B\u0259': '\u30B1',                           # kə -> ケ (word: "Rabauke", ipa: "ʁaˈbaʊ̯kə")
    '\u006B\u025B': '\u30B1',                           # kɛ -> ケ (word: "Inline-Skate", ipa: "ˈɪnlaɪ̯nˌskɛɪ̯t")
    '\u006B\u0069': '\u30AD',                           # ki -> キ (word: "Kies", ipa: "kiːs")
    '\u006B\u026A': '\u30AD',                           # kɪ -> キ (word: "Kind", ipa: "kɪnt")
    '\u006B\u006F': '\u30B3',                           # ko -> コ (word: "Melancholie", ipa: "melaŋkoˈliː")
    '\u006B\u0254': '\u30B3',                           # kɔ -> コ (word: "kommt", ipa: "kɔmt")
    '\u006B\u0075': '\u30AF',                           # ku -> ク (word: "Kuh", ipa: "kuː")
    '\u006B\u028A': '\u30AF',                           # kʊ -> ク (word: "Zukunft", ipa: "ˈt͡suːˌkʊnft")
    '\u006B\u0079': '\u30AD\u30E5',                     # ky -> キュ (word: "kühl", ipa: "kyːl")
    '\u006B\u028F': '\u30AD\u30E5',                     # kʏ -> キュ (word: "Küche", ipa: "ˈkʏçə")
    '\u006B\u00F8': '\u30B3\u30A7',                     # kø -> コェ (word: "Köter", ipa: "ˈkøːtɐ")
    '\u006B\u0153': '\u30B3\u30A7',                     # kœ -> コェ (word: "Körperteil", ipa: "ˈkœʁpɐˌtaɪ̯l")
    '\u006B\u006C\u0329': '\u30B1\u30EB',               # kl̩ -> ケル (word: "Ferkel", ipa: "ˈfɛʁkl̩")
    '\u006B\u006E\u0329': '\u30B1\u30F3',               # kn̩ -> ケン (word: "Wolken", ipa: "ˈvɔlkn̩")

    # L
    '\u006C': '\u30EB',                                 # l -> ル (word: "alt", ipa: "alt")
    '\u006C\u0061': '\u30E9',                           # la -> ラ (word: "Deutschland", ipa: "ˈdɔɪ̯t͡ʃlant")
    '\u006C\u0250': '\u30E9',                           # lɐ -> ラ (word: "Fehler", ipa: "ˈfeːlɐ")
    '\u006C\u0065': '\u30EC',                           # le -> レ (word: "Problem", ipa: "pʁoˈbleːm")
    '\u006C\u0259': '\u30EC',                           # lə -> レ (word: "Schule", ipa: "ˈʃuːlə")
    '\u006C\u025B': '\u30EC',                           # lɛ -> レ (word: "Niederländisch", ipa: "ˈniːdɐˌlɛndɪʃ")
    '\u006C\u0069': '\u30EA',                           # li -> リ (word: "Juli", ipa: "ˈjuːli")
    '\u006C\u026A': '\u30EA',                           # lɪ -> リ (word: "Frühling", ipa: "ˈfʁyːlɪŋ")
    '\u006C\u006F': '\u30ED',                           # lo -> ロ (word: "flogen", ipa: "floːɡn̩")
    '\u006C\u0254': '\u30ED',                           # lɔ -> ロ (word: "Ballon", ipa: "baˈlɔŋ")
    '\u006C\u0075': '\u30EB',                           # lu -> ル (word: "Blume", ipa: "ˈbluːmə")
    '\u006C\u028A': '\u30EB',                           # lʊ -> ル (word: "Flusses", ipa: "ˈflʊsəs")
    '\u006C\u0079': '\u30EA\u30E5',                     # ly -> リュ (word: "Glühbirne", ipa: "ˈɡlyːˌbɪʁnə")
    '\u006C\u028F': '\u30EA\u30E5',                     # lʏ -> リュ (word: "flüssig", ipa: "ˈflʏsɪç")
    '\u006C\u00F8': '\u30EC',                           # lø -> レ (word: "flöten", ipa: "ˈfløːtn̩")
    '\u006C\u0153': '\u30EC',                           # lœ -> レ (word: "Glöckchen", ipa: "ˈɡlœkçən")
    '\u006C\u006E\u0329': '\u30EC\u30F3',               # ln̩ -> レン (word: "holen", ipa: "ˌhoːln̩")

    # M
    '\u006D': '\u30E0',                                 # m -> ム (word: "Film", ipa: "fɪlm")
    '\u006D\u0061': '\u30DE',                           # ma -> マ (word: "Mann", ipa: "man")
    '\u006D\u0250': '\u30DE',                           # mɐ -> マ (word: "Zimmer", ipa: "ˈt͡sɪmɐ")
    '\u006D\u0065': '\u30E1',                           # me -> メ (word: "Melancholie", ipa: "melaŋkoˈliː")
    '\u006D\u0259': '\u30E1',                           # mə -> メ (word: "Blume", ipa: "ˈbluːmə")
    '\u006D\u025B': '\u30E1',                           # mɛ -> メ (word: "März", ipa: "mɛʁt͡s")
    '\u006D\u0069': '\u30DF',                           # mi -> ミ (word: "Familie", ipa: "faˈmiːli̯ə")
    '\u006D\u026A': '\u30DF',                           # mɪ -> ミ (word: "Mittag", ipa: "ˈmɪtaːk")
    '\u006D\u006F': '\u30E2',                           # mo -> モ (word: "Moment", ipa: "moˈmɛnt")
    '\u006D\u0254': '\u30E2',                           # mɔ -> モ (word: "Morgen", ipa: "ˈmɔʁɡn̩")
    '\u006D\u0075': '\u30E0',                           # mu -> ム (word: "Musik", ipa: "muˈziːk")
    '\u006D\u028A': '\u30E0',                           # mʊ -> ム (word: "Mutter", ipa: "ˈmʊtɐ")
    '\u006D\u0079': '\u30DF\u30E5',                     # my -> ミュ (word: "gemütlich", ipa: "ɡəˈmyːtlɪç")
    '\u006D\u028F': '\u30DF\u30E5',                     # mʏ -> ミュ (word: "Müller", ipa: "ˈmʏlɐ")
    '\u006D\u00F8': '\u30E1',                           # mø -> メ (word: "Möwen", ipa: "ˈmøːvn̩")
    '\u006D\u0153': '\u30E1',                           # mœ -> メ (word: "Mörder", ipa: "ˈmœʁdɐ")
    '\u006D\u006C\u0329': '\u30E1\u30EB',               # ml̩ -> メル (word: "Himmel", ipa: "ˈhɪml̩")
    '\u006D\u006E\u0329': '\u30E1\u30F3',               # mn̩ -> メン (word: "Aldhelmen", ipa: "ˈalthɛlmn̩")
    '\u006D\u02C8\u0070\u006A\u0075': '\u30F3\u30D4\u30E5',  # mˈpju -> ンピュ (word: "Computer", ipa: "kɔmˈpjuːtɐ")

    # N
    '\u006E': '\u30F3',                                 # n -> ン (word: "Deutschland", ipa: "ˈdɔɪ̯t͡ʃlant")
    '\u014B': '\u30F3\u30B0',                           # ŋ -> ング (word: "lang", ipa: "laŋ")
    '\u006E\u0061': '\u30CA',                           # na -> ナ (word: "Monat", ipa: "ˈmoːnat")
    '\u006E\u0250': '\u30CA',                           # nɐ -> ナ (word: "Donnerstag", ipa: "ˈdɔnɐsˌtaːk")
    '\u006E\u0065': '\u30CD',                           # ne -> ネ (word: "Schnee", ipa: "ʃneː")
    '\u006E\u0259': '\u30CD',                           # nə -> ネ (word: "Biene", ipa: "ˈbiːnə")
    '\u006E\u025B': '\u30CD',                           # nɛ -> ネ (word: "schnell", ipa: "ʃnɛl")
    '\u006E\u0069': '\u30CB',                           # ni -> ニ (word: "Universität", ipa: "ˌunivɛʁziˈtɛːt")
    '\u006E\u026A': '\u30CB',                           # nɪ -> ニ (word: "Sonnenfinsternis", ipa: "ˈzɔnənˌfɪnstɐnɪs")
    '\u006E\u006F': '\u30CE',                           # no -> ノ (word: "November", ipa: "noˈvɛmbɐ")
    '\u006E\u0254': '\u30CE',                           # nɔ -> ノ (word: "neun", ipa: "nɔɪ̯n")
    '\u006E\u0075': '\u30CC',                           # nu -> ヌ (word: "Januar", ipa: "ˈjanuaːɐ̯")
    '\u006E\u028A': '\u30CC',                           # nʊ -> ヌ (word: "Subregnum", ipa: "zʊpˈʁeːɡnʊm")
    '\u006E\u0079': '\u30CB\u30E5',                     # ny -> ニュ (word: "Akronym", ipa: "ˌakʁoˈnyːm")
    '\u006E\u028F': '\u30CB\u30E5',                     # nʏ -> ニュ (word: "schnüffeln", ipa: "ˈʃnʏfl̩n")
    '\u006E\u00F8': '\u30CB\u30A7',                     # nø -> ニェ (word: "schnökern", ipa: "ˈʃnøːkɐn")
    '\u006E\u0153': '\u30CB\u30A7',                     # nœ -> ニェ (word: "Knöchel", ipa: "ˈknœçl̩")
    '\u014B\u0250': '\u30F3\u30AC',                     # ŋɐ -> ンガ (word: "Finger", ipa: "ˈfɪŋɐ")
    '\u014B\u0259': '\u30F3\u30B2',                     # ŋə -> ンゲ (word: "fangen", ipa: "ˈfaŋən")
    '\u014B\u006B': '\u30F3\u30AF',                     # ŋk -> ンク (word: "Bank", ipa: "baŋk")
    '\u006E\u006C\u0329': '\u30CD\u30EB',               # nl̩ -> ネル (word: "Tunnel", ipa: "ˈtʊnl̩")
    '\u006E\u006E\u0329': '\u30CD\u30F3',               # nn̩ -> ネン (word: "zehnen", ipa: "ˈt͡seːnn̩")
    '\u014B\u006B\u0259': '\u30F3\u30B1',               # ŋkə -> ンケ (word: "danke", ipa: "ˈdaŋkə")
    '\u014B\u006B\u006C\u0329': '\u30F3\u30B1\u30EB',   # ŋkl̩ -> ンケル (word: "Dunkelheit", ipa: "ˈdʊŋkl̩haɪ̯t")
    '\u014B\u006B\u006E\u0329': '\u30F3\u30B1\u30F3',   # ŋkn̩ -> ンケン (word: "denken", ipa: "ˈdɛŋkn̩")

    # P
    '\u0070': '\u30D7',                                 # p -> プ (word: "Problem", ipa: "pʁoˈbleːm")
    '\u0070\u0061': '\u30D1',                           # pa -> パ (word: "Japan", ipa: "ˈjaːpan")
    '\u0070\u0250': '\u30D1',                           # pɐ -> パ (word: "Klapperstorch", ipa: "ˈklapɐˌʃtɔʁç")
    '\u0070\u0065': '\u30DA',                           # pe -> ペ (word: "Peter", ipa: "ˈpeːtɐ")
    '\u0070\u0259': '\u30DA',                           # pə -> ペ (word: "Lupe", ipa: "ˈluːpə")
    '\u0070\u025B': '\u30DA',                           # pɛ -> ペ (word: "Person", ipa: "pɛʁˈzoːn")
    '\u0070\u0069': '\u30D4',                           # pi -> ピ (word: "spielen", ipa: "ˈʃpiːlən")
    '\u0070\u026A': '\u30D4',                           # pɪ -> ピ (word: "Beispiel", ipa: "ˈbaɪ̯ˌʃpiːl")
    '\u0070\u006F': '\u30DD',                           # po -> ポ (word: "Potenz", ipa: "ˌpoˈtɛnt͡s")
    '\u0070\u0254': '\u30DD',                           # pɔ -> ポ (word: "Sport", ipa: "ʃpɔʁt")
    '\u0070\u0075': '\u30D7',                           # pu -> プ (word: "pudern", ipa: "ˈpuːdɐn")
    '\u0070\u028A': '\u30D7',                           # pʊ -> プ (word: "Pulver", ipa: "ˈpʊlfɐ")
    '\u0070\u0079': '\u30D4\u30E5',                     # py -> ピュ (word: "spürte", ipa: "ˈʃpyːɐ̯tə")
    '\u0070\u028F': '\u30D4\u30E5',                     # pʏ -> ピュ (word: "pünktlich", ipa: "ˈpʏŋktlɪç")
    '\u0070\u006C\u0329': '\u30DA\u30EB',               # pl̩ -> ペル (word: "Ampel", ipa: "ˈampl̩")
    '\u0070\u006E\u0329': '\u30DA\u30F3',               # pn̩ -> ペン (word: "Wappen", ipa: "ˈvapn̩")
    '\u0070\u0361\u0066': '\u30D7\u30D5',               # p͡f -> プフ (word: "Baumstumpf", ipa: "ˈbaʊ̯mˌʃtʊmp͡f")
    '\u0070\u0361\u0066\u0061': '\u30D5\u30A1',         # p͡fa -> ファ (word: "Pfad", ipa: "p͡faːt") (p is rather silent here so I'll not use プ)
    '\u0070\u0361\u0066\u0250':'\u30D7\u30D5\u30A1',    # p͡fɐ -> プファ (word: "Kupfer", ipa: "ˈkʊp͡fɐ") (p in p͡fɐ is voiced more than p͡fa)
    '\u0070\u0361\u0066\u0065': '\u30D5\u30A7',         # p͡fe -> フェ (word: "Pferd", ipa: "p͡feːɐ̯t")
    '\u0070\u0361\u0066\u0259': '\u30D5\u30A7',         # p͡fə -> フェ (word: "Pferd", ipa: "p͡feːɐ̯t")
    '\u0070\u0361\u0066\u025B': '\u30D5\u30A7',         # p͡fɛ -> フェ (word: "Mauerpfeffer", ipa: "ˈmaʊ̯ɐˌp͡fɛfɐ")
    '\u0070\u0361\u0066\u0069': '\u30D5\u30A3',         # p͡fi -> フィ (word: "empfiehl", ipa: "ɛmˈp͡fiːl")
    '\u0070\u0361\u0066\u026A': '\u30D5\u30A3',         # p͡fɪ -> フィ (word: "Pfiffikus", ipa: "ˈp͡fɪfikʊs")
    '\u0070\u0361\u0066\u006F': '\u30D5\u30A9',         # p͡fo -> フォ (word: "empfohlen", ipa: "ɛmˈp͡foːlən")
    '\u0070\u0361\u0066\u0254': '\u30D5\u30A9',         # p͡fɔ -> フォ (word: "Pforzheim", ipa: "ˈp͡fɔʁt͡shaɪ̯m")
    '\u0070\u0361\u0066\u0075': '\u30D5',               # p͡fu -> フ (word: "Pfuhl", ipa: "p͡fuːl")
    '\u0070\u0361\u0066\u028A': '\u30D5',               # p͡fʊ -> フ (word: "Impfung", ipa: "ˈɪmp͡fʊŋ")
    '\u0070\u0361\u0066\u0079': '\u30D5\u30E5',         # p͡fy -> フュ (word: "Pfühl", ipa: "p͡fyːl")
    '\u0070\u0361\u0066\u028F': '\u30D5\u30E5',         # p͡fʏ -> フュ (word: "Pfütze", ipa: "ˈp͡fʏt͡sə")
    '\u0070\u0361\u0066\u00F8': '\u30D5\u30A9\u30A7',   # p͡fø -> フォェ (word: "empföhle", ipa: "ɛmˈp͡føːlə")
    '\u0070\u0361\u0066\u0153': '\u30D5\u30A9\u30A7',   # p͡fœ -> フォェ (word: "Pförtner", ipa: "ˈp͡fœʁtnɐ")
    '\u0070\u0361\u0066\u006E\u0329': '\u30D7\u30D5\u30A7\u30F3',  # p͡fn̩ -> プフェン (word: "Tropfen", ipa: "ˈtʁɔp͡fn̩")
    '\u0070\u0361\u0066\u006C\u0329': '\u30D7\u30D5\u30A7\u30EB',  # p͡fl̩ -> プフェル (word: "Apfel", ipa: "ˈap͡fl̩")

    # Q
    '\u006B\u0076\u0061': '\u30AF\u30A1',               # kva -> クァ (word: "Qualm", ipa: "kvalm")
    '\u006B\u0076\u0250': '\u30AF\u30A1',               # kvɐ -> クァ (word: "Äquer", ipa: "ˈɛːkvɐ")
    '\u006B\u0076\u0065': '\u30AF\u30A7',               # kve -> クェ (word: "quer", ipa: "kveːɐ̯")
    '\u006B\u0076\u0259': '\u30AF\u30A7',               # kvə -> クェ (word: "obliquen", ipa: "oˈbliːkvən")
    '\u006B\u0076\u025B': '\u30AF\u30A7',               # kvɛ -> クェ (word: "Quelle", ipa: "ˈkvɛlə")
    '\u006B\u0076\u0069': '\u30AF\u30A3',               # kvi -> クィ (word: "Requiem", ipa: "ˈʁeːkviɛm")
    '\u006B\u0076\u026A': '\u30AF\u30A3',               # kvɪ -> クィ (word: "Quiz", ipa: "kvɪs")
    '\u006B\u0076\u006F': '\u30AF\u30A9',               # kvo -> クォ (word: "Quotient", ipa: "ˌkvoˈt͡si̯ɛnt")
    '\u006B\u0076\u0254': '\u30AF\u30A9',               # kvɔ -> クォ (word: "gequollen", ipa: "ɡəˈkvɔlən")

    # R
    '\u0072': '\u30EB',                                 # r -> ル (word: "Döner", ipa: "ˈdœnɛr")
    '\u0281': '\u30A2',                                 # ʁ -> ア (word: "Farbe", ipa: "ˈfaʁbə")
    '\u0281\u0061': '\u30E9',                           # ʁa -> ラ (word: "Frau", ipa: "fʁaʊ̯")
    '\u0281\u0250': '\u30E9',                           # ʁɐ -> ラ (word: "ihrer", ipa: "ˈiːʁɐ")
    '\u0281\u0251': '\u30E9',                           # ʁɑ -> ラ (word: "Orange", ipa: "oˈʁɑ̃ːʒə")
    '\u0281\u0065': '\u30EC',                           # ʁe -> レ (word: "drehte", ipa: "ˈdʁeːtə")
    '\u0281\u0259': '\u30EC',                           # ʁə -> レ (word: "fahren", ipa: "ˈfaːʁən")
    '\u0281\u025B': '\u30EC',                           # ʁɛ -> レ (word: "sprechen", ipa: "ˈʃpʁɛçn̩")
    '\u0281\u0069': '\u30EA',                           # ʁi -> リ (word: "Horizont", ipa: "hoʁiˈt͡sɔnt")
    '\u0281\u026A': '\u30EA',                           # ʁɪ -> リ (word: "April", ipa: "aˈpʁɪl")
    '\u0281\u006F': '\u30ED',                           # ʁo -> ロ (word: "Problem", ipa: "pʁoˈbleːm")
    '\u0281\u0254': '\u30ED',                           # ʁɔ -> ロ (word: "Freund", ipa: "fʁɔɪ̯nt")
    '\u0281\u0075': '\u30EB',                           # ʁu -> ル (word: "Februar", ipa: "ˈfeːbʁuaːɐ̯")
    '\u0281\u028A': '\u30EB',                           # ʁʊ -> ル (word: "Dämmerung", ipa: "ˈdɛməʁʊŋ")
    '\u0281\u0079': '\u30EA\u30E5',                     # ʁy -> リュ (word: "Frühstück", ipa: "ˈfʁyːˌʃtʏk")
    '\u0281\u028F': '\u30EA\u30E5',                     # ʁʏ -> リュ (word: "zurück", ipa: "t͡suˈʁʏk")
    '\u0281\u00F8': '\u30ED',                           # ʁø -> ロ (word: "Kröte", ipa: "ˈkʁøːtə")
    '\u0281\u0153': '\u30ED',                           # ʁœ -> ロ (word: "bröckeln", ipa: "ˈbʁœkl̩n")
    '\u0281\u006C\u0329': '\u30EC\u30EB',               # ʁl̩ -> レル (word: "Arel", ipa: "ˈaʁl̩")
    '\u0281\u006E\u0329': '\u30EC\u30F3',               # ʁn̩ -> レン (word: "Moosbeeren", ipa: "ˈmoːsˌbeːʁn̩")
    '\u0281\u00E7\u0000': '\u30A2\u30B7\u30E5',         # ʁç -> アシュ (word: "Storch", ipa: "ʃtɔʁç")

    # S
    '\u0073': '\u30B9',                                 # s -> ス (word: "Bus", ipa: "bʊs")
    '\u0283': '\u30B7\u30E5',                           # ʃ -> シュ (word: "Schnee", ipa: "ʃneː")
    '\u0073\u0061': '\u30B5',                           # sa -> サ (word: "Xanten", ipa: "ˈksantn̩")
    '\u0073\u0250': '\u30B5',                           # sɐ -> サ (word: "Wasser", ipa: "ˈvasɐ")
    '\u007A\u0061': '\u30B6',                           # za -> ザ (word: "sein", ipa: "zaɪ̯n")
    '\u007A\u0250': '\u30B6',                           # zɐ -> ザ (word: "Häuser", ipa: "ˈhɔɪ̯zɐ")
    '\u0073\u0065': '\u30BB',                           # se -> セ (word: "Odyssee", ipa: "odʏˈseː")
    '\u0073\u0259': '\u30BB',                           # sə -> セ (word: "Straße", ipa: "ˈʃtʁaːsə")
    '\u0073\u025B': '\u30BB',                           # sɛ -> セ (word: "Sex", ipa: "sɛks")
    '\u007A\u0065': '\u30BC',                           # ze -> ゼ (word: "See", ipa: "zeː")
    '\u007A\u0259': '\u30BC',                           # zə -> ゼ (word: "Börse", ipa: "ˈbœʁzə")
    '\u007A\u025B': '\u30BC',                           # zɛ -> ゼ (word: "sechs", ipa: "zɛks")
    '\u0073\u0069': '\u30B9\u30A3',                     # si -> スィ (word: "Lexikon", ipa: "ˈlɛksikɔn")
    '\u0073\u026A': '\u30B9\u30A3',                     # sɪ -> スィ (word: "Essig", ipa: "ˈɛsɪç")
    '\u007A\u0069': '\u30BA\u30A3',                     # zi -> ズィ (word: "Universität", ipa: "ˌunivɛʁziˈtɛːt")
    '\u007A\u026A': '\u30BA\u30A3',                     # zɪ -> ズィ (word: "sich", ipa: "zɪç")
    '\u0073\u006F': '\u30BD',                           # so -> ソ (word: "Espresso", ipa: "ˌɛsˈpʁɛso")
    '\u0073\u0254': '\u30BD',                           # sɔ -> ソ (word: "Software", ipa: "ˈsɔftˌvɛːɐ̯")
    '\u007A\u006F': '\u30BE',                           # zo -> ゾ (word: "Sohn", ipa: "zoːn")
    '\u007A\u0254': '\u30BE',                           # zɔ -> ゾ (word: "Sommer", ipa: "ˈzɔmɐ")
    '\u0073\u0075': '\u30B9',                           # su -> ス (word: "Sexualität", ipa: "ˌsɛksualiˈtɛːt")
    '\u0073\u028A': '\u30B9',                           # sʊ -> ス (word: "Impressum", ipa: "ɪmˈpʁɛsʊm")
    '\u007A\u0075': '\u30BA',                           # zu -> ズ (word: "Suche", ipa: "ˈzuːxə")
    '\u007A\u028A': '\u30BA',                           # zʊ -> ズ (word: "subtil", ipa: "zʊpˈtiːl")
    '\u007A\u0079': '\u30C5\u30E5',                     # zy -> ヅュ (word: "Süd", ipa: "ˈzyːt")
    '\u0283\u0061': '\u30B7\u30E3',                     # ʃa -> シャ (word: "entscheiden", ipa: "ɛntˈʃaɪ̯dn̩")
    '\u0283\u0250': '\u30B7\u30E3',                     # ʃɐ -> シャ (word: "zwitschern", ipa: "ˈt͡svɪt͡ʃɐn")
    '\u0283\u0251': '\u30B7\u30E3',                     # ʃɑ -> シャ (word: "Chance", ipa: "ʃɑ̃ːs")
    '\u0283\u0065': '\u30B7\u30A7',                     # ʃe -> シェ (word: "geschehen", ipa: "ɡəˈʃeːən")
    '\u0283\u0259': '\u30B7\u30A7',                     # ʃə -> シェ (word: "Tasche", ipa: "ˈtaʃə")    
    '\u0283\u025B': '\u30B7\u30A7',                     # ʃɛ -> シェ (word: "Geschenk", ipa: "ɡəˈʃɛŋk")
    '\u0283\u0069': '\u30B7',                           # ʃi -> シ (word: "Maschine", ipa: "maˌʃiːnə")
    '\u0283\u026A': '\u30B7',                           # ʃɪ -> シ (word: "Schiff", ipa: "ʃɪf")
    '\u0283\u006F': '\u30B7\u30E7',                     # ʃo -> ショ (word: "schon", ipa: "ʃoːn")
    '\u0283\u0254': '\u30B7\u30E7',                     # ʃɔ -> ショ (word: "Schornstein", ipa: "ˈʃɔʁnˌʃtaɪ̯n")
    '\u0283\u0075': '\u30B7\u30E5',                     # ʃu -> シュ (word: "Schule", ipa: "ˈʃuːlə")
    '\u0283\u028A': '\u30B7\u30E5',                     # ʃʊ -> シュ (word: "Schuld", ipa: "ʃʊlt")
    '\u0283\u0079': '\u30B7\u30E5',                     # ʃy -> シュ (word: "Schüler", ipa: "ˈʃyːlɐ")
    '\u0283\u0079': '\u30B7\u30E5',                     # ʃy -> シュ (word: "Geschützturm", ipa: "ɡəˈʃʏt͡sˌtʊʁm")
    '\u0283\u00F8': '\u30B7\u30E7',                     # ʃø -> ショ (word: "schön", ipa: "ʃøːn")
    '\u0283\u0153': '\u30B7\u30E7',                     # ʃœ -> ショ (word: "schöpfen", ipa: "ˈʃœp͡fn̩")
    '\u0073\u006C\u0329': '\u30BB\u30EB',               # sl̩ -> セル (word: "Stöpsel", ipa: "ˈʃtœpsl̩")
    '\u0073\u006E\u0329': '\u30BB\u30F3',               # sn̩ -> セン (word: "wissen", ipa: "ˈvɪsn̩")
    '\u007A\u006C\u0329': '\u30BC\u30EB',               # zl̩ -> ゼル (word: "Insel", ipa: "ˈɪnzl̩")
    '\u007A\u006E\u0329': '\u30BC\u30F3',               # zn̩ -> ゼン (word: "tausend", ipa: "ˈtaʊ̯zn̩t")
    '\u0283\u006C\u0329': '\u30B7\u30A7\u30EB',         # ʃl̩ -> シェル (word: "rascheln", ipa: "ˈʁaʃl̩n")
    '\u0283\u006E\u0329': '\u30B7\u30A7\u30F3',         # ʃn̩ -> シェン (word: "rauschenden", ipa: "ˈʁaʊ̯ʃn̩dən")

    # T
    '\u0074': '\u30C8',                                 # t -> ト (word: "alt", ipa: "alt")
    '\u0074\u0061': '\u30BF',                           # ta -> タ (word: "Stand", ipa: "ʃtant")
    '\u0074\u0250': '\u30BF',                           # tɐ -> タ (word: "Mutter", ipa: "ˈmʊtɐ")
    '\u0074\u0065': '\u30C6',                           # te -> テ (word: "stehen", ipa: "ˈʃteːən") 
    '\u0074\u0259': '\u30C6',                           # tə -> テ (word: "heute", ipa: "ˈhɔɪ̯tə")
    '\u0074\u025B': '\u30C6',                           # tɛ -> テ (word: "Hotel", ipa: "hoˈtɛl")
    '\u0074\u0069': '\u30C6\u30A3',                     # ti -> ティ (word: "Tier", ipa: "tiːɐ̯")
    '\u0074\u026A': '\u30C6\u30A3',                     # tɪ -> ティ (word: "Tisch", ipa: "tɪʃ")
    '\u0074\u006F': '\u30C8',                           # to -> ト (word: "Oktober", ipa: "ɔkˈtoːbɐ")
    '\u0074\u0254': '\u30C8',                           # tɔ -> ト (word: "Storch", ipa: "ʃtɔʁç")
    '\u0074\u0075': '\u30C8\u30A5',                     # tu -> トゥ (word: "Eigentum", ipa: "ˈaɪ̯ɡn̩tuːm")
    '\u0074\u028A': '\u30C8\u30A5',                     # tʊ -> トゥ (word: "Wachturm", ipa: "ˈvaxˌtʊʁm")
    '\u0074\u0079': '\u30C8\u30A5',                     # ty -> トゥ (word: "Tür", ipa: "tyːɐ̯")
    '\u0074\u028F': '\u30C8\u30A5',                     # tʏ -> トゥ (word: "Frühstück", ipa: "ˈfʁyːˌʃtʏk")
    '\u0074\u00F8': '\u30C8',                           # tø -> ト (word: "töten", ipa: "ˈtøːtn̩")
    '\u0074\u0153': '\u30C8',                           # tœ -> ト (word: "Stöpsel", ipa: "ˈʃtœpsl̩")
    '\u0074\u006C\u0329': '\u30C6\u30EB',               # tl̩ -> テル (word: "Mistel", ipa: "ˈmɪstl̩")
    '\u0074\u006E\u0329': '\u30C6\u30F3',               # tn̩ -> テン (word: "antworten", ipa: "ˈantˌvɔʁtn̩")
    '\u0074\u0361\u0073': '\u30C4',                     # t͡s -> ツ (word: "Geburtstag", ipa: "ɡəˈbuːɐ̯t͡sˌtaːk")
    '\u0074\u0361\u0283': '\u30C1\u30E5',               # t͡ʃ -> チュ (word: "Deutschland", ipa: "ˈdɔɪ̯t͡ʃlant")
    '\u0074\u0361\u0283\u0061': '\u30C1\u30E3',         # t͡ʃa -> チャ (word: "chartern", ipa: "ˈt͡ʃaʁtɐn")
    '\u0074\u0361\u0283\u0250': '\u30C1\u30E3',         # t͡ʃɐ -> チャ (word: "zwitschern", ipa: "ˈt͡svɪt͡ʃɐn")
    '\u0074\u0361\u0283\u0065': '\u30C1\u30A7',         # t͡ʃe -> チェ (word: "Tschetschenien", ipa: "t͡ʃɛˈt͡ʃeːni̯ən")
    '\u0074\u0361\u0283\u0259': '\u30C1\u30A7',         # t͡ʃə -> チェ (word: "Deutsche", ipa: "ˈdɔɪ̯t͡ʃə")
    '\u0074\u0361\u0283\u025B': '\u30C1\u30A7',         # t͡ʃɛ -> チェ (word: "chatten", ipa: "ˈt͡ʃɛtn̩")
    '\u0074\u0361\u0283\u0069': '\u30C1',               # t͡ʃi -> チ (word: "Litschi", ipa: "ˈlɪt͡ʃi")
    '\u0074\u0361\u0283\u026A': '\u30C1',               # t͡ʃɪ -> チ (word: "chillen", ipa: "ˈt͡ʃɪlən")
    '\u0074\u0361\u0283\u006F': '\u30C1\u30E7',         # t͡ʃo -> チョ (word: "Macho", ipa: "ˈmat͡ʃo")
    '\u0074\u0361\u0283\u0254': '\u30C1\u30E7',         # t͡ʃɔ -> チョ (word: "abchoppen", ipa: "ˈapˌt͡ʃɔpn̩")
    '\u0074\u0361\u0283\u0075': '\u30C1\u30E5',         # t͡ʃu -> チュ (word: "Ketschua", ipa: "ˈkɛt͡ʃua")
    '\u0074\u0361\u0283\u028A': '\u30C1\u30E5',         # t͡ʃʊ -> チュ (word: "Kautschuk", ipa: "ˈkaʊ̯t͡ʃʊk")
    '\u0074\u0361\u0283\u0079': '\u30C1\u30E5',         # t͡ʃy -> チュ (word: "tschüs", ipa: "t͡ʃyːs")
    '\u0074\u0361\u0283\u028F': '\u30C1\u30E5',         # t͡ʃʏ -> チュ (word: "tschüss", ipa: "t͡ʃʏs")
    '\u0074\u0361\u0283\u00F8': '\u30C1\u30E7',         # t͡ʃø -> チョ (no word for this mapping yet)
    '\u0074\u0361\u0283\u0153': '\u30C1\u30E7',         # t͡ʃœ -> チョ (no word for this mapping yet)
    '\u0074\u0361\u0283\u006E\u0329': '\u30C1\u30A7\u30F3',  # t͡ʃn̩ -> チェン (word: "quatschen", ipa: "ˈkvat͡ʃn̩")
    '\u0074\u0361\u0283\u006C\u0329': '\u30C1\u30A7\u30EB',  # t͡ʃl̩ -> チェル (word: "verhätscheln", ipa: "fɛɐ̯ˈhɛt͡ʃl̩n")

    # V
    '\u0076\u0061': '\u30F4\u30A1',                     # va -> ヴァ (word: "Wald", ipa: "valt")
    '\u0076\u0250': '\u30F4\u30A1',                     # vɐ -> ヴァ (word: "Pulverschnee", ipa: "ˈpʊlvɐˌʃneː")
    '\u0076\u0251': '\u30F4\u30A1',                     # vɑ -> ヴァ (word: "Revanche", ipa: "ʁeˈvɑ̃ːʃ")
    '\u0076\u0065': '\u30F4\u30A7',                     # ve -> ヴェ (word: "Wesen", ipa: "ˈveːzn̩")
    '\u0076\u0259': '\u30F4\u30A7',                     # və -> ヴェ (word: "Alternative", ipa: "ˌaltɛʁnaˈtiːvə")
    '\u0076\u025B': '\u30F4\u30A7',                     # vɛ -> ヴェ (word: "November", ipa: "noˈvɛmbɐ")
    '\u0076\u0069': '\u30F4\u30A3',                     # vi -> ヴィ (word: "violett", ipa: "vi̯oˈlɛt")
    '\u0076\u026A': '\u30F4\u30A3',                     # vɪ -> ヴィ (word: "Wind", ipa: "vɪnt")
    '\u0076\u006F': '\u30F4\u30A9',                     # vo -> ヴォ (word: "wohnen", ipa: "ˈvoːnən")
    '\u0076\u0254': '\u30F4\u30A9',                     # vɔ -> ヴォ (word: "Wort", ipa: "vɔʁt")
    '\u0076\u0075': '\u30F4',                           # vu -> ヴ (word: "Wut", ipa: "vuːt")
    '\u0076\u028A': '\u30F4',                           # vʊ -> ヴ (word: "wurde", ipa: "ˈvʊʁdə")
    '\u0076\u0079' :'\u30F4\u30E5',                     # vy -> ヴュ (word: "Wüste", ipa: "ˈvyːstə")
    '\u0076\u028F' :'\u30F4\u30E5',                     # vʏ -> ヴュ (word: "Würfel", ipa: "ˈvʏʁfl̩")
    '\u0076\u00F8': '\u30F4\u30A9\u30A8',               # vø -> ヴォエ (word: "gewöhnlich", ipa: "ɡəˈvøːnlɪç")
    '\u0076\u0153': '\u30F4\u30A9\u30A8',               # vœ -> ヴォエ (word: "Wörterbuch", ipa: "ˈvœʁtɐˌbuːx")
    '\u0076\u006C\u0329': '\u30F4\u30A7\u30EB',         # vl̩ -> ヴェル (word: "Level", ipa: "ˈlɛvl̩")
    '\u0076\u006E\u0329': '\u30F4\u30A7\u30F3',         # vn̩ -> ヴェン (word: "Möwen", ipa: "ˈmøːvn̩")
    

    # Z
    '\u0074\u0361\u0073\u0061': '\u30C4\u30A1',         # t͡sa -> ツァ (word: "Zeit", ipa: "t͡saɪ̯t")
    '\u0074\u0361\u0073\u0250': '\u30C4\u30A1',         # t͡sɐ -> ツァ (word: "Kratzer", ipa: "ˈkʁat͡sɐ")
    '\u0074\u0361\u0073\u0065': '\u30C4\u30A7',         # t͡se -> ツェ (word: "zehn", ipa: "t͡seːn")
    '\u0074\u0361\u0073\u0259': '\u30C3\u30C4\u30A7',   # t͡sə -> ッツェ (word: "Katze", ipa: "ˈkat͡sə")
    '\u0074\u0361\u0073\u025B': '\u30C4\u30A7',         # t͡sɛ -> ツェ (word: "Dezember", ipa: "deˈt͡sɛmbɐ")
    '\u0074\u0361\u0073\u0069': '\u30C4\u30A3',         # t͡si -> ツィ (word: "ziehen", ipa: "ˈt͡siːən")
    '\u0074\u0361\u0073\u026A': '\u30C4\u30A3',         # t͡sɪ -> ツィ (word: "Zimmer", ipa: "ˈt͡sɪmɐ")
    '\u0074\u0361\u0073\u006F': '\u30C4\u30A9',         # t͡so -> ツォ (word: "zog", ipa: "t͡soːk")
    '\u0074\u0361\u0073\u0254': '\u30C4\u30A9',         # t͡sɔ -> ツォ (word: "Horizont", ipa: "hoʁiˈt͡sɔnt")
    '\u0074\u0361\u0073\u0075': '\u30C4',               # t͡su -> ツ (word: "zurück", ipa: "t͡suˈʁʏk")
    '\u0074\u0361\u0073\u028A': '\u30C4',               # t͡sʊ -> ツ (word: "Zucker", ipa: "ˈt͡sʊkɐ")
    '\u0074\u0361\u0073\u0079': '\u30C5\u30E5',         # t͡sy -> ヅュ (word: "Zyklon", ipa: "ˈt͡syklɔn")
    '\u0074\u0361\u0073\u028F': '\u30C5\u30E5',         # t͡sʏ -> ヅュ (word: "angezündet", ipa: "ˈanɡəˌt͡sʏndət")
    '\u0074\u0361\u0073\u00F8': '\u30C5\u30E7',         # t͡sø -> ヅョ (word: "zögern", ipa: "ˈt͡søːɡɐn")
    '\u0074\u0361\u0073\u0153': '\u30C5\u30E7',         # t͡sœ -> ヅョ (word: "Zöllner", ipa: "ˈt͡sœlnɐ")
    '\u0074\u0361\u0073\u006C\u0329': '\u30C4\u30A7\u30EB',  # t͡sl̩ -> ツェル (word: "Wurzel", ipa: "ˈvʊʁt͡sl̩")
    '\u0074\u0361\u0073\u006E\u0329': '\u30C4\u30A7\u30F3',  # t͡sn̩ -> ツェン (word: "ächzen", ipa: "ˈɛçt͡sn̩")
    '\u0361\u0073\u0074\u006E\u0329': '\u30C4\u30C6\u30F3',  # ͡stn -> ツテン (word: "letzten", ipa: "ˈlɛt͡stn̩")
    
    # Edge cases for T with preceding short vowel
    '\u0062\u025B\u0074': '\u30D9\u30C3\u30C8',  # bɛt -> ベット (Short "t" with preceding short vowel as "BETT")
    '\u0074\u0061\u0074': '\u30BF\u30C3\u30C8',  # tat -> タット (Short "t" with preceding short vowel as "sTADT")
    '\u02C8\u006C\u025B\u0074': '\u30EC\u30C3\u30C8',  # ˈlɛt -> レット (Short "t" with preceding short vowel as "vioLETT")

    # Edge cases for CH "x" (Pronunciation of "ch" depends on the preceding vowel
    '\u0078\u0259': '\u30C3\u30D8',  # xə -> ッヘ (Short "che" as "spraCHE")
    '\u0078\u0074\u0259': '\u30C3\u30D8\u30C6',  # xtə -> ッヘテ (Short "chte" as "daCHTE")
    '\u0061\u0078\u0074': '\u30A2\u30C3\u30CF\u30C8',  # axt -> アッハト (Short "cht" with preceding "a" as "ACHT")
    '\u006D\u0061\u0078\u0074': '\u30DE\u30C3\u30CF\u30C8',  # -> マッハト (Short "cht" with preceding "ma" as "MACHT")
    '\u006E\u0061\u0078': '\u30CA\u30C3\u30CF',  # nax -> ナッハ (Short "ch" with preceding "na" as "NACH")
    '\u006E\u0254\u0078': '\u30CE\u30C3\u30DB',  # nɔx -> ノッホ (Short "ch" with preceding "no" as "NOCH")
    '\u0064\u0254\u0078': '\u30C9\u30C3\u30DB',  # dɔx -> ドッホ (Short "ch" with preceding "do" as "DOCH")
    '\u0064\u0061\u0078': '\u30C0\u30C3\u30CF',  # dax -> ダッハ (Short "ch" with preceding "da" as "daCH")
    '\u0078\u006E': '\u30C3\u30D8\u30F3',  # xn -> ッヘン (Short "chen" as "spraCHEN")
    '\u028A\u032F\u0078': '\u30A6\u30C3\u30D5',  # ʊ̯x -> ウッフ (Short "uch" as "raUCH")
    '\u0062\u0061\u0078': '\u30D0\u30C3\u30CF',  # bax -> バッハ (Short "ch" with preceding "ba" as "BACH")
    '\u0074\u0254\u0078': '\u30C8\u30C3\u30DB',  # tɔx -> トッホ (Short "ch" with preceding "to" as "toCHter")
    '\u006B\u0254\u0078': '\u30B3\u30C3\u30DB',  # kɔx -> コッホ (Short "ch" with preceding "ko" as "koCHt")
    '\u0281\u0061\u0078': '\u30E9\u30C3\u30CF',  # ʁax -> ラッハ (Short "ch" with preceding "ra" as "herunterbraCHst")
    '\u0076\u0061\u0078': '\u30F4\u30A1\u30C3\u30CF',  # vax -> ヴァッハ
    '\u0283\u0061\u0078': '\u30B7\u30E3\u30C3\u30CF',  # ʃax -> シャッハ (Short "ch" with preceding "scha" as "schaCH")
    '\u0066\u006C\u0075\u0078\u028A': '',  # fluxʊ -> フルッフ
    '\u0076\u0254\u0078': '\u30F4\u30A9\u30C3\u30DB',  # vɔx -> ヴォッホ (Short "ch" with preceding "wo" as "mittWOCH")
    '\u0076\u0254\u0078\u0259': '\u30F4\u30A9\u30C3\u30D8',  # vɔxə -> ヴォッヘ (Short "ch" with preceding "wo" as "mittWOCH")
    '\u006E\u0061\u02D0\u0078': '\u30CA\u30C3\u30CF',  # naːx -> ナッハ
    '\u0062\u0075\u02D0\u0078': '\u30D6\u30FC\u30C3\u30D5',  # buːx -> ブーッフ (Long "ch" with preceding "bu" as "BUCH")
    '\u0074\u0075\u02D0\u0078': '\u30C8\u30A5\u30FC\u30C3\u30D5',  # tuːx -> トゥーッフ (Long "ch" with predecing "tu" as "TUCH")
    
    # Edge cases for N the middle of word as "nn", e.g. "soNNe"
    '\u02C8\u007A\u0254\u006E\u0259': '\u30BE\u30F3\u30CD',  # ˈzɔnə -> ゾンネ (Short "ne" as "soNNE")

    # Edge cases for M pronunciation, "ン" is pronuounced "m" when it is followed by a "b"
    '\u006D\u0062\u0061': '\u30F3\u30D0',               # mba -> ンバ (word: "Schwimmbad", ipa: "ˈʃvɪmbaːt")
    '\u006D\u0062\u0250': '\u30F3\u30D0',               # mbɐ -> ンバ (word: "Dezember", ipa: "deˈt͡sɛmbɐ")
    '\u006D\u0062\u0065': '\u30F3\u30D9',               # mbe -> ンベ (word: "Himbeereises", ipa: "ˈhɪmbeːɐ̯ˌʔaɪ̯zəs")
    '\u006D\u0062\u0259': '\u30F3\u30D9',               # mbə -> ンベ (word: "Bombe", ipa: "ˈbɔmbə") 
    '\u006D\u0062\u025B': '\u30F3\u30D9',               # mbɛ -> ンベ (word: "Bamberger", ipa: "ˈbambɛʁɡɐ")
    '\u006D\u0062\u0069': '\u30F3\u30D3',               # mbi -> ンビ (word: "ambivalent", ipa: "ambivaˈlɛnt")
    '\u006D\u0062\u026A': '\u30F3\u30D3',               # mbɪ -> ンビ (word: "Imbiss", ipa: "ˈɪmbɪs")
    '\u006D\u0062\u006F': '\u30F3\u30DC',               # mbo -> ンボ (word: "Tombola", ipa: "ˈtɔmbola")
    '\u006D\u0062\u0254': '\u30F3\u30DC',               # mbɔ -> ンボ (word: "Amboss", ipa: "ˈambɔs")
    '\u006D\u0062\u0075': '\u30F3\u30D6',               # mbu -> ンブ (word: "Ambulanz", ipa: "ambuˈlant͡s")
    '\u006D\u0062\u028A': '\u30F3\u30D6',               # mbʊ -> ンブ (word: "Hamburg", ipa: "ˈhambʊʁk")
    '\u006D\u0062\u0079': '\u30F3\u30D3\u30E5',         # mby -> ンビュ (word: "Stammbücher", ipa: "ˈʃtamˌbyːçɐ")
    '\u006D\u0062\u028F': '\u30F3\u30D3\u30E5',         # mbʏ -> ンビュ (word: "Heimbürgin", ipa: "ˈhaɪ̯mbʏʁɡɪn")
    '\u006D\u0062\u00F8': '\u30F3\u30DC\u30A7',         # mbø -> ンボェ 
    '\u006D\u0062\u0153': '\u30F3\u30DC\u30A7',         # mbœ -> ンボェ 
    '\u006D\u0062\u006C\u0329': '\u30F3\u30D9\u30EB',   # mbl̩ -> ンベル 
    '\u006D\u0062\u006E\u0329': '\u30F3\u30D9\u30F3',   # mbn̩ -> ンベン

    # Edge cases for M pronunciation, "ン" is pronuounced "m" when it is followed by a "p"
    '\u0070': '\u30D7',                                 # np -> プ (word: "Problem", ipa: "pʁoˈbleːm")
    '\u0070\u0061': '\u30D1',                           # npa -> パ (word: "Japan", ipa: "ˈjaːpan")
    '\u0070\u0250': '\u30D1',                           # npɐ -> パ (word: "Klapperstorch", ipa: "ˈklapɐˌʃtɔʁç")
    '\u0070\u0065': '\u30DA',                           # npe -> ペ (word: "Peter", ipa: "ˈpeːtɐ")
    '\u0070\u0259': '\u30DA',                           # npə -> ペ (word: "Lupe", ipa: "ˈluːpə")
    '\u0070\u025B': '\u30DA',                           # npɛ -> ペ (word: "Person", ipa: "pɛʁˈzoːn")
    '\u0070\u0069': '\u30D4',                           # npi -> ピ (word: "spielen", ipa: "ˈʃpiːlən")
    '\u0070\u026A': '\u30D4',                           # npɪ -> ピ (word: "Beispiel", ipa: "ˈbaɪ̯ˌʃpiːl")
    '\u0070\u006F': '\u30DD',                           # npo -> ポ (word: "Potenz", ipa: "ˌpoˈtɛnt͡s")
    '\u0070\u0254': '\u30DD',                           # npɔ -> ポ (word: "Sport", ipa: "ʃpɔʁt")
    '\u0070\u0075': '\u30D7',                           # npu -> プ (word: "pudern", ipa: "ˈpuːdɐn")
    '\u0070\u028A': '\u30D7',                           # npʊ -> プ (word: "Pulver", ipa: "ˈpʊlfɐ")
    '\u0070\u0079': '\u30D4\u30E5',                     # npy -> ピュ (word: "spürte", ipa: "ˈʃpyːɐ̯tə")
    '\u0070\u028F': '\u30D4\u30E5',                     # npʏ -> ピュ (word: "pünktlich", ipa: "ˈpʏŋktlɪç")
    '\u0070\u006C\u0329': '\u30DA\u30EB',               # npl̩ -> ペル (word: "Ampel", ipa: "ˈampl̩")
    '\u0070\u006E\u0329': '\u30DA\u30F3',               # npn̩ -> ペン (word: "Wappen", ipa: "ˈvapn̩")
    '\u0070\u0361\u0066': '\u30D7\u30D5',               # np͡f -> プフ (word: "Baumstumpf", ipa: "ˈbaʊ̯mˌʃtʊmp͡f")
    '\u0070\u0361\u0066\u006E\u0329': '\u30D7\u30D5\u30A7\u30F3',  # np͡fn̩ -> プフェン (word: "Tropfen", ipa: "ˈtʁɔp͡fn̩")
    '\u0070\u0361\u0066\u006C\u0329': '\u30D7\u30D5\u30A7\u30EB',  # np͡fl̩ -> プフェル (word: "Apfel", ipa: "ˈap͡fl̩")

    # Edge cases general
    '\u02D0\u0259': '\u30FC\u30D8',  # ːə -> ーヘ (word: "nahe", ipa: "ˈnaːə")
    '\u0073\u006E\u0329\u0074': '\u30B6\u30F3\u30AF\u30C8',  # sn̩t -> ザンクト	(word: "St. Lucia", ipa: "sn̩t ˈluːʃə")

    # Special characters
    '\u0000': '',  # NULL character should not map to anything, if not used
    '\u0020': '\u0020',  # Space character just maps to space again
    '\u002D': '',  # - -> 
    '\u0294': '',  # ʔ ->
    '\u02C8': '',  # ˈ -> 
    '\u02D0': '\u30FC',  # ː -> ー
    '\u02CC': '',  # ˌ ->
    '\u0329': '',  # ˌ ->
    '\u032F': '',  # ̯  ->
    '\u0303': '',  # ̃  -> 
    '\u0361': '',  # ͡  ->
}
